@@ -17,14 +17,14 @@ class FTP(ftplib.FTP):
             :param kwargs: named arguments
             :type dict:
         """
-        self.host = kwargs.get("host")
-        self.user = kwargs.get("user")
-        self.passwd = kwargs.get("passwd")
+        host = kwargs.get("host")
+        user = kwargs.get("user")
+        passwd = kwargs.get("passwd")
         self.callback = kwargs.get("progress")
         self.header_bytes = 33
         self.sent = 0
         self.file_size = 0
-        ftplib.FTP.__init__(self, self.host, self.user, self.passwd)
+        ftplib.FTP.__init__(self, host=host, user=user, passwd=passwd, timeout=30)
 
     def put(self, local_file, remote_file):
         """ copies file from local host to remote host
@@ -34,6 +34,7 @@ class FTP(ftplib.FTP):
             :type: string
         """
         with open(local_file, "rb") as open_local_file:
+
             def callback(data):
                 if self.callback:
                     size_data = sys.getsizeof(data) - self.header_bytes
@@ -43,6 +44,7 @@ class FTP(ftplib.FTP):
                         file_size=self.file_size,
                         sent=self.sent,
                     )
+
             self.storbinary(
                 cmd="STOR " + remote_file, fp=open_local_file, callback=callback
             )
@@ -55,6 +57,7 @@ class FTP(ftplib.FTP):
             :type: string
         """
         with open(local_file, "wb") as local_fh:
+
             def callback(data):
                 local_fh.write(data)
                 if self.callback:
@@ -65,4 +68,5 @@ class FTP(ftplib.FTP):
                         file_size=self.file_size,
                         sent=self.sent,
                     )
+
             self.retrbinary("RETR " + remote_file, callback)
